ExEventBus.ObanDrainer (ExEventBus v0.11.0)

Copy Markdown View Source

Implements a custom Drainer for Oban that allows to drain jobs specific to a given event handler.

Summary

Functions

drain(conf, opts)